@@ -11,12 +11,12 @@
 #include "kgetkjobadapter.h"
 
 #include "kget_debug.h"
-#include <QDebug>
 #include <KLocalizedString>
+#include <QDebug>
 
 KGetKJobAdapter::KGetKJobAdapter(QObject *parent, TransferHandler *transfer)
-  : KJob(parent),
-    m_transferHandler(transfer)
+    : KJob(parent)
+    , m_transferHandler(transfer)
 {
     setCapabilities(Killable | Suspendable);
 }
@@ -44,9 +44,10 @@ unsigned long KGetKJobAdapter::percent() const
 
 void KGetKJobAdapter::slotUpdateDescription()
 {
-    emit description(this, i18n("KGet Transfer"), 
-                    qMakePair(QString("source"), m_transferHandler->source().toString()),
-                    qMakePair(QString("destination"), m_transferHandler->dest().toString()));
+    Q_EMIT description(this,
+                       i18n("KGet Transfer"),
+                       qMakePair(QString("source"), m_transferHandler->source().toString()),
+                       qMakePair(QString("destination"), m_transferHandler->dest().toString()));
 
     emitSpeed(m_transferHandler->downloadSpeed());
     setProcessedAmount(KJob::Bytes, processedAmount(KJob::Bytes));
@@ -57,14 +58,14 @@ void KGetKJobAdapter::slotUpdateDescription()
 bool KGetKJobAdapter::doKill()
 {
     qCDebug(KGET_DEBUG) << "Kill of job adapter called:" << this << m_transferHandler->dest();
-    emit requestStop(this, m_transferHandler);
+    Q_EMIT requestStop(this, m_transferHandler);
     return KJob::doKill();
 }
 
 bool KGetKJobAdapter::doSuspend()
 {
     if (m_transferHandler->capabilities() & Transfer::Cap_Resuming) {
-        emit requestSuspend(this, m_transferHandler);
+        Q_EMIT requestSuspend(this, m_transferHandler);
         return true;
     }
 
@@ -73,6 +74,6 @@ bool KGetKJobAdapter::doSuspend()
 
 bool KGetKJobAdapter::doResume()
 {
-    emit requestResume(this, m_transferHandler);
+    Q_EMIT requestResume(this, m_transferHandler);
     return true;
 }
