@@ -9,13 +9,13 @@
 */
 
 #include "transferhistory.h"
-#include "ui/newtransferdialog.h"
-#include "settings.h"
-#include "ui/history/transferhistorycategorizedview.h"
-#include "ui/history/transferhistorycategorizeddelegate.h"
-#include "ui/history/rangetreewidget.h"
-#include "core/transferhistorystore.h"
 #include "core/job.h"
+#include "core/transferhistorystore.h"
+#include "settings.h"
+#include "ui/history/rangetreewidget.h"
+#include "ui/history/transferhistorycategorizeddelegate.h"
+#include "ui/history/transferhistorycategorizedview.h"
+#include "ui/newtransferdialog.h"
 
 #include "kget_debug.h"
 
@@ -26,30 +26,30 @@
 #include <QMenu>
 #include <QModelIndex>
 #include <QProgressBar>
-#include <QVariant>
 #include <QStandardItem>
+#include <QVariant>
 
 #include <QDebug>
 
-#include <KTreeWidgetSearchLine>
-#include <KRun>
-#include <kio/global.h>
-#include <QPushButton>
-#include <QDialogButtonBox>
-#include <QIcon>
 #include <KLocalizedString>
+#include <KRun>
+#include <KTreeWidgetSearchLine>
+#include <QDialogButtonBox>
 #include <QFontDatabase>
+#include <QIcon>
+#include <QPushButton>
 #include <QStandardPaths>
+#include <kio/global.h>
 
 TransferHistory::TransferHistory(QWidget *parent)
-    : KGetSaveSizeDialog("TransferHistory", parent),
-    m_rangeType(TransferHistory::Date),
-    m_progressBar(new QProgressBar(this)),
-    m_iconModeEnabled(true)
+    : KGetSaveSizeDialog("TransferHistory", parent)
+    , m_rangeType(TransferHistory::Date)
+    , m_progressBar(new QProgressBar(this))
+    , m_iconModeEnabled(true)
 {
     setAttribute(Qt::WA_DeleteOnClose);
     setWindowTitle(i18n("Transfer History"));
-    //Setup Ui-Parts from Designer
+    // Setup Ui-Parts from Designer
     auto *mainWidget = new QWidget(this);
 
     setupUi(mainWidget);
@@ -74,7 +74,7 @@ TransferHistory::TransferHistory(QWidget *parent)
     vboxLayout->addWidget(m_view);
     vboxLayout->addWidget(m_progressBar);
 
-    auto * buttonBox = new QDialogButtonBox(mainWidget);
+    auto *buttonBox = new QDialogButtonBox(mainWidget);
     buttonBox->clear();
     buttonBox->addButton(QDialogButtonBox::Close);
     vboxLayout->addWidget(buttonBox);
@@ -92,12 +92,10 @@ TransferHistory::TransferHistory(QWidget *parent)
     connect(m_openFile, SIGNAL(triggered()), this, SLOT(slotOpenFile()));
     connect(clearButton, &QAbstractButton::clicked, this, &TransferHistory::slotClear);
     connect(rangeType, SIGNAL(activated(int)), this, SLOT(slotLoadRangeType(int)));
-    connect(m_view, SIGNAL(deletedTransfer(QString,QModelIndex)),
-                    SLOT(slotDeleteTransfer(QString,QModelIndex)));
+    connect(m_view, SIGNAL(deletedTransfer(QString, QModelIndex)), SLOT(slotDeleteTransfer(QString, QModelIndex)));
     connect(m_view, SIGNAL(doubleClicked(QModelIndex)), SLOT(slotOpenFile(QModelIndex)));
     connect(m_store, &TransferHistoryStore::loadFinished, this, &TransferHistory::slotLoadFinished);
-    connect(m_store, &TransferHistoryStore::elementLoaded,
-                     this, &TransferHistory::slotElementLoaded);
+    connect(m_store, &TransferHistoryStore::elementLoaded, this, &TransferHistory::slotElementLoaded);
     connect(searchBar, SIGNAL(textChanged(QString)), m_view, SLOT(setFilterRegExp(QString)));
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
@@ -111,14 +109,14 @@ TransferHistory::~TransferHistory()
 
 QSize TransferHistory::sizeHint() const
 {
-    QSize sh(800,600);
+    QSize sh(800, 600);
     return sh;
 }
 
 void TransferHistory::slotDeleteTransfer()
 {
     if (!m_iconModeEnabled) {
-        auto *range_view = qobject_cast <RangeTreeWidget *> (m_view);
+        auto *range_view = qobject_cast<RangeTreeWidget *>(m_view);
 
         slotDeleteTransfer(range_view->currentItem(0)->text());
 
@@ -158,7 +156,7 @@ void TransferHistory::slotWriteDefault()
 void TransferHistory::slotDownload()
 {
     if (!m_iconModeEnabled) {
-        NewTransferDialogHandler::showNewTransferDialog(QUrl(((RangeTreeWidget *) m_view)->currentItem(0)->text()));
+        NewTransferDialogHandler::showNewTransferDialog(QUrl(((RangeTreeWidget *)m_view)->currentItem(0)->text()));
     }
 }
 
@@ -167,8 +165,8 @@ void TransferHistory::contextMenuEvent(QContextMenuEvent *event)
     Q_UNUSED(event)
 
     if (!m_iconModeEnabled) {
-        auto *range_view = qobject_cast <RangeTreeWidget *> (m_view);
-        if(range_view->currentIndex().parent().isValid()) {
+        auto *range_view = qobject_cast<RangeTreeWidget *>(m_view);
+        if (range_view->currentIndex().parent().isValid()) {
             auto *contextMenu = new QMenu(this);
             contextMenu->addAction(actionDownload);
             contextMenu->addAction(actionDelete_Selected);
@@ -185,15 +183,14 @@ void TransferHistory::slotOpenFile(const QModelIndex &index)
     QString file;
 
     if (!m_iconModeEnabled) {
-        auto *range_view = qobject_cast <RangeTreeWidget *> (m_view);
+        auto *range_view = qobject_cast<RangeTreeWidget *>(m_view);
         file = range_view->currentItem(1)->text();
-    }
-    else {
-        auto *categorized_view = qobject_cast <TransferHistoryCategorizedView *> (m_view);
+    } else {
+        auto *categorized_view = qobject_cast<TransferHistoryCategorizedView *>(m_view);
         file = categorized_view->data(index, TransferHistoryCategorizedDelegate::RoleDest).toString();
     }
 
-    //qDebug() << "Try to open the file : " << file;
+    // qDebug() << "Try to open the file : " << file;
     if (!file.isEmpty()) {
         new KRun(QUrl::fromLocalFile(file), this, true);
     }
@@ -202,24 +199,23 @@ void TransferHistory::slotOpenFile(const QModelIndex &index)
 void TransferHistory::hideEvent(QHideEvent *event)
 {
     Q_UNUSED(event)
-    disconnect(watcher, &QFileSystemWatcher::directoryChanged, this, &TransferHistory::slotAddTransfers);//Prevent reloading of TransferHistory when saving
+    disconnect(watcher, &QFileSystemWatcher::directoryChanged, this, &TransferHistory::slotAddTransfers); // Prevent reloading of TransferHistory when saving
     deleteLater();
 }
 
 QString TransferHistory::statusText(int status) const
 {
-    switch (status)
-    {
-        case Job::Running:
-            return i18nc("The transfer is running", "Running");
-        case Job::Stopped:
-            return i18nc("The transfer is stopped", "Stopped");
-        case Job::Aborted:
-            return i18nc("The transfer is aborted", "Aborted");
-        case Job::Finished:
-            return i18nc("The transfer is finished", "Finished");
-        default:
-            return QString();
+    switch (status) {
+    case Job::Running:
+        return i18nc("The transfer is running", "Running");
+    case Job::Stopped:
+        return i18nc("The transfer is stopped", "Stopped");
+    case Job::Aborted:
+        return i18nc("The transfer is aborted", "Aborted");
+    case Job::Finished:
+        return i18nc("The transfer is finished", "Finished");
+    default:
+        return QString();
     }
 }
 
@@ -227,69 +223,58 @@ void TransferHistory::slotLoadRangeType(int type)
 {
     m_rangeType = type;
     if (m_iconModeEnabled) {
-        auto *cat_view = qobject_cast <TransferHistoryCategorizedView *> (m_view);
+        auto *cat_view = qobject_cast<TransferHistoryCategorizedView *>(m_view);
         cat_view->clear();
-        switch(type)
-        {
-            case TransferHistory::Size :
-                cat_view->setCategorizedDelegate(new SizeCategorizedDelegate());
-                break;
-            case TransferHistory::Date :
-                cat_view->setCategorizedDelegate(new DateCategorizedDelegate());
-                break;
-            default:
-                cat_view->setCategorizedDelegate(new HostCategorizedDelegate());
+        switch (type) {
+        case TransferHistory::Size:
+            cat_view->setCategorizedDelegate(new SizeCategorizedDelegate());
+            break;
+        case TransferHistory::Date:
+            cat_view->setCategorizedDelegate(new DateCategorizedDelegate());
+            break;
+        default:
+            cat_view->setCategorizedDelegate(new HostCategorizedDelegate());
         }
     } else {
-        auto *range_view = qobject_cast <RangeTreeWidget *> (m_view);
+        auto *range_view = qobject_cast<RangeTreeWidget *>(m_view);
         auto *font = new QFontMetrics(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
         range_view->clear();
 
         range_view->setLabels(QStringList() << i18n("Source File") << i18n("Destination") << i18n("Time") << i18n("File Size") << i18n("Status"));
         range_view->setRangeDelegate(nullptr);
 
-        switch(m_rangeType)
-        {
-            case TransferHistory::Host :
-                range_view->setRangeDelegate(new HostRangeDelegate(this));
-                break;
-            case TransferHistory::Size :
-                range_view->addRange(QVariant(0), QVariant(1024 * 1024),
-                                                  i18n("Less than 1MiB"));
-                range_view->addRange(QVariant(1024 * 1024), QVariant(1024 * 1024 * 10),
-                                                  i18n("Between 1MiB-10MiB"));
-                range_view->addRange(QVariant(1024 * 1024 * 10), QVariant(1024 * 1024 * 100),
-                                                  i18n("Between 10MiB-100MiB"));
-                range_view->addRange(QVariant(1024 * 1024 * 100), QVariant(1024 * 1024 *1024),
-                                                  i18n("Between 100MiB-1GiB"));
-                range_view->addRange(QVariant((double) 1024 * 1024 * 1024), QVariant((double) 1024 * 1024 * 1024 * 10),
-                                                  i18n("More than 1GiB"));
-                break;
-            default:
-                range_view->addRange(QVariant(0), QVariant(1), i18n("Today"));
-                range_view->addRange(QVariant(1), QVariant(7), i18n("Last week"));
-                range_view->addRange(QVariant(7), QVariant(30), i18n("Last month"));
-                range_view->addRange(QVariant(30), QVariant(-1), i18n("A long time ago"));
+        switch (m_rangeType) {
+        case TransferHistory::Host:
+            range_view->setRangeDelegate(new HostRangeDelegate(this));
+            break;
+        case TransferHistory::Size:
+            range_view->addRange(QVariant(0), QVariant(1024 * 1024), i18n("Less than 1MiB"));
+            range_view->addRange(QVariant(1024 * 1024), QVariant(1024 * 1024 * 10), i18n("Between 1MiB-10MiB"));
+            range_view->addRange(QVariant(1024 * 1024 * 10), QVariant(1024 * 1024 * 100), i18n("Between 10MiB-100MiB"));
+            range_view->addRange(QVariant(1024 * 1024 * 100), QVariant(1024 * 1024 * 1024), i18n("Between 100MiB-1GiB"));
+            range_view->addRange(QVariant((double)1024 * 1024 * 1024), QVariant((double)1024 * 1024 * 1024 * 10), i18n("More than 1GiB"));
+            break;
+        default:
+            range_view->addRange(QVariant(0), QVariant(1), i18n("Today"));
+            range_view->addRange(QVariant(1), QVariant(7), i18n("Last week"));
+            range_view->addRange(QVariant(7), QVariant(30), i18n("Last month"));
+            range_view->addRange(QVariant(30), QVariant(-1), i18n("A long time ago"));
         }
 
         QList<int> list = Settings::historyColumnWidths();
 
-        if (!list.isEmpty())
-        {
+        if (!list.isEmpty()) {
             int j = 0;
-            foreach (int i, list)
-            {
+            foreach (int i, list) {
                 range_view->setColumnWidth(j, i);
                 j++;
             }
-        }
-        else
-        {
+        } else {
             range_view->setColumnWidth(0, 200);
             range_view->setColumnWidth(1, 250);
-            range_view->setColumnWidth(2, font->width(QDate::currentDate().toString()));
-            range_view->setColumnWidth(3, font->width("1500000 KiB"));
-            range_view->setColumnWidth(4, font->width(i18nc("the transfer has been finished", "Finished")));
+            range_view->setColumnWidth(2, font->horizontalAdvance(QDate::currentDate().toString()));
+            range_view->setColumnWidth(3, font->horizontalAdvance("1500000 KiB"));
+            range_view->setColumnWidth(4, font->horizontalAdvance(i18nc("the transfer has been finished", "Finished")));
         }
     }
 
@@ -318,20 +303,17 @@ void TransferHistory::slotSetIconMode()
     slotLoadRangeType(m_rangeType);
 
     connect(searchBar, SIGNAL(textChanged(QString)), m_view, SLOT(setFilterRegExp(QString)));
-    connect(m_view, SIGNAL(deletedTransfer(QString,QModelIndex)),
-                    SLOT(slotDeleteTransfer(QString,QModelIndex)));
+    connect(m_view, SIGNAL(deletedTransfer(QString, QModelIndex)), SLOT(slotDeleteTransfer(QString, QModelIndex)));
     connect(m_view, SIGNAL(doubleClicked(QModelIndex)), SLOT(slotOpenFile(QModelIndex)));
 }
 
 void TransferHistory::slotElementLoaded(int number, int total, const TransferHistoryItem &item)
 {
-    m_progressBar->setValue(number*100/total);
+    m_progressBar->setValue(number * 100 / total);
 
     if (m_iconModeEnabled) {
-            ((TransferHistoryCategorizedView *) m_view)->addData(
-                    item.dateTime().date(), item.source(), item.dest(), item.size());
-    }
-    else {
+        ((TransferHistoryCategorizedView *)m_view)->addData(item.dateTime().date(), item.source(), item.dest(), item.size());
+    } else {
         QVariantList attributeList;
         attributeList.append(item.source());
         attributeList.append(item.dest());
@@ -340,17 +322,15 @@ void TransferHistory::slotElementLoaded(int number, int total, const TransferHis
         attributeList.append(statusText(item.state()));
 
         QVariant data;
-        if(m_rangeType == TransferHistory::Date) {
+        if (m_rangeType == TransferHistory::Date) {
             QDate date = item.dateTime().date();
             data = QVariant(date.daysTo(QDate::currentDate()));
-        }
-        else if(m_rangeType == TransferHistory::Host) {
+        } else if (m_rangeType == TransferHistory::Host) {
             data = QVariant(item.source());
-        }
-        else {
+        } else {
             data = QVariant(item.size());
         }
-        ((RangeTreeWidget *) m_view)->add(data, attributeList);
+        ((RangeTreeWidget *)m_view)->add(data, attributeList);
     }
 }
 
