@@ -10,11 +10,11 @@
 */
 
 #include "transfersview.h"
-#include "settings.h"
-#include "transfersviewdelegate.h"
-#include "transferdetails.h"
-#include "core/transfertreemodel.h"
 #include "core/kget.h"
+#include "core/transfertreemodel.h"
+#include "settings.h"
+#include "transferdetails.h"
+#include "transfersviewdelegate.h"
 
 #include "kget_debug.h"
 
@@ -24,20 +24,20 @@
 #include <QAction>
 #include <QDebug>
 #include <QDropEvent>
+#include <QGroupBox>
 #include <QHeaderView>
 #include <QMenu>
 #include <QSignalMapper>
-#include <QGroupBox>
 
-TransfersView::TransfersView(QWidget * parent)
+TransfersView::TransfersView(QWidget *parent)
     : QTreeView(parent)
 {
-//     setItemsExpandable(false);
+    //     setItemsExpandable(false);
     setRootIsDecorated(false);
     setAnimated(true);
     setAllColumnsShowFocus(true);
     header()->setDefaultAlignment(Qt::AlignCenter);
-    header()->setMinimumSectionSize(80);    
+    header()->setMinimumSectionSize(80);
     header()->setContextMenuPolicy(Qt::CustomContextMenu);
     header()->setSectionsClickable(true);
     m_headerMenu = new QMenu(header());
@@ -50,40 +50,37 @@ TransfersView::TransfersView(QWidget * parent)
     setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
     setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
 
-    connect(header(), &QWidget::customContextMenuRequested,
-                      this, &TransfersView::slotShowHeaderMenu);
+    connect(header(), &QWidget::customContextMenuRequested, this, &TransfersView::slotShowHeaderMenu);
     connect(header(), &QHeaderView::sectionCountChanged, this, &TransfersView::populateHeaderActions);
     connect(header(), &QHeaderView::sectionMoved, this, &TransfersView::slotSectionMoved);
     connect(header(), &QHeaderView::sectionResized, this, &TransfersView::slotSaveHeader);
     connect(this, &TransfersView::doubleClicked, this, &TransfersView::slotItemActivated);
     connect(this, &TransfersView::collapsed, this, &TransfersView::slotItemCollapsed);
-    connect(KGet::model(), SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)), 
-            this,          SLOT(closeExpandableDetails(QModelIndex,int,int)));
+    connect(KGet::model(), SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)), this, SLOT(closeExpandableDetails(QModelIndex, int, int)));
 }
 
 TransfersView::~TransfersView()
 {
 }
 
-void TransfersView::setModel(QAbstractItemModel * model)
+void TransfersView::setModel(QAbstractItemModel *model)
 {
     QTreeView::setModel(model);
     int nGroups = model->rowCount(QModelIndex());
 
-    for(int i = 0; i < nGroups; i++)
-    {
+    for (int i = 0; i < nGroups; i++) {
         qCDebug(KGET_DEBUG) << "openEditor for row " << i;
         openPersistentEditor(model->index(i, TransferTreeModel::Status, QModelIndex()));
     }
 
     QByteArray loadedState = QByteArray::fromBase64(Settings::headerState().toLatin1());
     if (loadedState.isEmpty()) {
-        setColumnWidth(0 , 230);
+        setColumnWidth(0, 230);
     } else {
         header()->restoreState(loadedState);
     }
 
-    //Workaround if the saved headerState is corrupted
+    // Workaround if the saved headerState is corrupted
     header()->setRootIndex(QModelIndex());
 
     populateHeaderActions();
@@ -91,7 +88,7 @@ void TransfersView::setModel(QAbstractItemModel * model)
     connect(model, &QAbstractItemModel::rowsRemoved, this, &TransfersView::toggleMainGroup);
 }
 
-void TransfersView::dropEvent(QDropEvent * event)
+void TransfersView::dropEvent(QDropEvent *event)
 {
     QModelIndex dropIndex = indexAt(event->pos());
     QTreeView::dropEvent(event);
@@ -99,16 +96,14 @@ void TransfersView::dropEvent(QDropEvent * event)
     setExpanded(dropIndex, true);
 }
 
-void TransfersView::rowsInserted(const QModelIndex & parent, int start, int end)
+void TransfersView::rowsInserted(const QModelIndex &parent, int start, int end)
 {
     qCDebug(KGET_DEBUG) << "TransfersView::rowsInserted";
 
-    if(!parent.isValid())
-    {
+    if (!parent.isValid()) {
         qCDebug(KGET_DEBUG) << "parent is not valid " << start << "  " << end;
 
-        for(int i = start; i <= end; i++)
-        {
+        for (int i = start; i <= end; i++) {
             qCDebug(KGET_DEBUG) << "openEditor for row " << i;
             openPersistentEditor(model()->index(i, TransferTreeModel::Status, parent));
         }
@@ -128,7 +123,7 @@ void TransfersView::populateHeaderActions()
     auto *columnMapper = new QSignalMapper(this);
     connect(columnMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped), this, &TransfersView::slotHideSection);
 
-    //Create for each column an action with the column-header as name
+    // Create for each column an action with the column-header as name
     QVector<QAction *> orderedMenuItems(header()->count());
     for (int i = 0; i < header()->count(); ++i) {
         auto *action = new QAction(this);
@@ -141,7 +136,7 @@ void TransfersView::populateHeaderActions()
         columnMapper->setMapping(action, i);
     }
 
-    //append the sorted actions
+    // append the sorted actions
     for (int i = 0; i < orderedMenuItems.count(); ++i) {
         m_headerMenu->addAction(orderedMenuItems[i]);
     }
@@ -158,10 +153,10 @@ void TransfersView::slotSectionMoved(int logicalIndex, int oldVisualIndex, int n
 {
     Q_UNUSED(logicalIndex)
 
-    //first item is the title, so increase the indexes by one
+    // first item is the title, so increase the indexes by one
     ++oldVisualIndex;
     ++newVisualIndex;
-    QList<QAction*> actions = m_headerMenu->actions();
+    QList<QAction *> actions = m_headerMenu->actions();
 
     QAction *before = actions.last();
     if (newVisualIndex + 1 < actions.count()) {
@@ -184,7 +179,7 @@ void TransfersView::slotSaveHeader()
     Settings::self()->save();
 }
 
-void TransfersView::dragMoveEvent ( QDragMoveEvent * event )
+void TransfersView::dragMoveEvent(QDragMoveEvent *event)
 {
     Q_UNUSED(event)
 
@@ -192,54 +187,53 @@ void TransfersView::dragMoveEvent ( QDragMoveEvent * event )
     QTreeView::dragMoveEvent(event);
 }
 
-void TransfersView::slotItemActivated(const QModelIndex & index)
+void TransfersView::slotItemActivated(const QModelIndex &index)
 {
     if (!index.isValid())
         return;
 
-    TransferTreeModel * transferTreeModel = KGet::model();
-    ModelItem * item = transferTreeModel->itemFromIndex(index);
-    auto *view_delegate = static_cast <TransfersViewDelegate *> (itemDelegate());
+    TransferTreeModel *transferTreeModel = KGet::model();
+    ModelItem *item = transferTreeModel->itemFromIndex(index);
+    auto *view_delegate = static_cast<TransfersViewDelegate *>(itemDelegate());
 
-    if(!item)
+    if (!item)
         return;
 
-    if(!item->isGroup() && index.column() == 0) {
-        if(!view_delegate->isExtended(index)) {
+    if (!item->isGroup() && index.column() == 0) {
+        if (!view_delegate->isExtended(index)) {
             TransferHandler *handler = item->asTransfer()->transferHandler();
             QWidget *widget = getDetailsWidgetForTransfer(handler);
 
             m_editingIndexes.append(index);
             view_delegate->extendItem(widget, index);
-        }
-        else {
+        } else {
             m_editingIndexes.removeAll(index);
             view_delegate->contractItem(index);
         }
         KGet::actionCollection()->action("transfer_show_details")->setChecked(view_delegate->isExtended(index));
-    } else if (!item->isGroup() && static_cast<TransferModelItem*>(item)->transferHandler()->status() == Job::Finished) {
-        new KRun(static_cast<TransferModelItem*>(item)->transferHandler()->dest(), this);
+    } else if (!item->isGroup() && static_cast<TransferModelItem *>(item)->transferHandler()->status() == Job::Finished) {
+        new KRun(static_cast<TransferModelItem *>(item)->transferHandler()->dest(), this);
     }
 }
 
-void TransfersView::slotItemCollapsed(const QModelIndex & index)
+void TransfersView::slotItemCollapsed(const QModelIndex &index)
 {
     if (!index.isValid())
         return;
 
-    TransferTreeModel * transferTreeModel = KGet::model();
-    ModelItem * item = transferTreeModel->itemFromIndex(index);
-    auto *view_delegate = static_cast <TransfersViewDelegate *> (itemDelegate());
+    TransferTreeModel *transferTreeModel = KGet::model();
+    ModelItem *item = transferTreeModel->itemFromIndex(index);
+    auto *view_delegate = static_cast<TransfersViewDelegate *>(itemDelegate());
 
-    if(!item)
+    if (!item)
         return;
-    
-    if(item->isGroup()) {
-        TransferGroupHandler * groupHandler = item->asGroup()->groupHandler();
+
+    if (item->isGroup()) {
+        TransferGroupHandler *groupHandler = item->asGroup()->groupHandler();
         QList<TransferHandler *> transfers = groupHandler->transfers();
 
-        foreach(TransferHandler * transfer, transfers) {
-            qCDebug(KGET_DEBUG) << "Transfer = " << transfer->source().toString(); 
+        foreach (TransferHandler *transfer, transfers) {
+            qCDebug(KGET_DEBUG) << "Transfer = " << transfer->source().toString();
             view_delegate->contractItem(KGet::model()->itemFromTransferHandler(transfer)->index());
         }
     }
@@ -250,16 +244,15 @@ void TransfersView::toggleMainGroup()
     // show or hide the first group header if there's only one download group
     int nGroups = model()->rowCount(QModelIndex());
 
-    if(nGroups <= 1) {
+    if (nGroups <= 1) {
         setRootIndex(model()->index(0, 0, QModelIndex()));
-    }
-    else {
+    } else {
         setRootIndex(QModelIndex());
     }
-    header()->setRootIndex(QModelIndex());//HACK: else the header isn't visible with no visible items in the view
+    header()->setRootIndex(QModelIndex()); // HACK: else the header isn't visible with no visible items in the view
 }
 
-void TransfersView::rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end)
+void TransfersView::rowsAboutToBeRemoved(const QModelIndex &parent, int start, int end)
 {
     Q_UNUSED(parent)
     Q_UNUSED(start)
@@ -275,9 +268,9 @@ void TransfersView::slotShowHeaderMenu(const QPoint &point)
 
 void TransfersView::closeExpandableDetails(const QModelIndex &transferIndex)
 {
-    auto *view_delegate = static_cast <TransfersViewDelegate *> (itemDelegate());
-    
-    if(transferIndex.isValid()) {
+    auto *view_delegate = static_cast<TransfersViewDelegate *>(itemDelegate());
+
+    if (transferIndex.isValid()) {
         view_delegate->contractItem(transferIndex);
         m_editingIndexes.removeAll(transferIndex);
     } else {
@@ -286,7 +279,7 @@ void TransfersView::closeExpandableDetails(const QModelIndex &transferIndex)
     }
 }
 
-void TransfersView::selectionChanged(const QItemSelection & selected, const QItemSelection & deselected)
+void TransfersView::selectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
 {
     Q_UNUSED(deselected)
     if (!selected.indexes().isEmpty()) {
@@ -303,7 +296,7 @@ void TransfersView::closeExpandableDetails(const QModelIndex &parent, int rowSta
     Q_UNUSED(rowStart)
     Q_UNUSED(rowEnd)
 
-    auto *view_delegate = static_cast <TransfersViewDelegate *> (itemDelegate());
+    auto *view_delegate = static_cast<TransfersViewDelegate *>(itemDelegate());
 
     view_delegate->contractAll();
     m_editingIndexes.clear();
@@ -319,5 +312,3 @@ QWidget *TransfersView::getDetailsWidgetForTransfer(TransferHandler *handler)
 
     return groupBox;
 }
-
-
